@@ -1,30 +1,33 @@
-from randovania.game_description.resources.resource_type import ResourceType
+from __future__ import annotations
+
+from typing import Self
 
 
 class PickupIndex:
+    __slots__ = ("_index",)
     _index: int
 
     @property
-    def resource_type(self) -> ResourceType:
-        return ResourceType.PICKUP_INDEX
+    def long_name(self) -> str:
+        return f"PickupIndex {self._index}"
 
     @property
-    def long_name(self) -> str:
-        return "PickupIndex {}".format(self._index)
+    def short_name(self) -> str:
+        return self.long_name
 
     def __init__(self, index: int):
         self._index = index
 
-    def __lt__(self, other: "PickupIndex") -> bool:
+    def __lt__(self, other: PickupIndex) -> bool:
         return self._index < other._index
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.long_name
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return self._index
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         return isinstance(other, PickupIndex) and other._index == self._index
 
     @property
@@ -32,9 +35,9 @@ class PickupIndex:
         return self._index
 
     @property
-    def as_json(self):
+    def as_json(self) -> int:
         return self._index
 
     @classmethod
-    def from_json(cls, value):
+    def from_json(cls, value: int) -> Self:
         return cls(value)
