@@ -1,13 +1,16 @@
+from __future__ import annotations
+
 from asyncio import CancelledError
+from unittest.mock import MagicMock
 
 import pytest
-from mock import MagicMock
 
-from randovania.gui.lib.background_task_mixin import BackgroundTaskMixin, AbortBackgroundTask
+from randovania.gui.lib.background_task_mixin import BackgroundTaskMixin
+from randovania.lib.background_task import AbortBackgroundTask
 
 
-@pytest.fixture(name="force_sync_mixin")
-def _force_sync_mixin():
+@pytest.fixture
+def force_sync_mixin():
     mixin = BackgroundTaskMixin()
 
     def run_in_background_thread(work, starting_message):
@@ -17,7 +20,6 @@ def _force_sync_mixin():
     return mixin
 
 
-@pytest.mark.asyncio
 async def test_run_in_background_success(force_sync_mixin):
     # Setup
     def target(progress_update):
@@ -30,18 +32,16 @@ async def test_run_in_background_success(force_sync_mixin):
     assert result == 5
 
 
-@pytest.mark.asyncio
 async def test_run_in_background_async_cancelled(force_sync_mixin):
     # Setup
     def target(progress_update):
-        raise AbortBackgroundTask()
+        raise AbortBackgroundTask
 
     # Run
     with pytest.raises(CancelledError):
         await force_sync_mixin.run_in_background_async(target, "Hello World")
 
 
-@pytest.mark.asyncio
 async def test_run_in_background_async_exception(force_sync_mixin):
     class WeirdError(Exception):
         pass
